==> odata-client-microsoft-dynamics-0.1.45-sources.jar: microsoft/dynamics/crm/complex/QueryWithEntityMetadata.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "QueryMetadata", 
    "DependantEntitiesCollection"})
@JsonInclude(Include.NON_NULL)
public class QueryWithEntityMetadata implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("QueryMetadata")
    protected QueryMetadata queryMetadata;

    @JsonProperty("DependantEntitiesCollection")
    protected DependentEntityMetadataCollection dependantEntitiesCollection;

    protected QueryWithEntityMetadata() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.QueryWithEntityMetadata";
    }

    @Property(name="QueryMetadata")
    @JsonIgnore
    public Optional<QueryMetadata> getQueryMetadata() {
        return Optional.ofNullable(queryMetadata);
    }

    public QueryWithEntityMetadata withQueryMetadata(QueryMetadata queryMetadata) {
        QueryWithEntityMetadata _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.QueryWithEntityMetadata");
        _x.queryMetadata = queryMetadata;
        return _x;
    }

    @Property(name="DependantEntitiesCollection")
    @JsonIgnore
    public Optional<DependentEntityMetadataCollection> getDependantEntitiesCollection() {
        return Optional.ofNullable(dependantEntitiesCollection);
    }

    public QueryWithEntityMetadata withDependantEntitiesCollection(DependentEntityMetadataCollection dependantEntitiesCollection) {
        QueryWithEntityMetadata _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.QueryWithEntityMetadata");
        _x.dependantEntitiesCollection = dependantEntitiesCollection;
        return _x;
    }

    public QueryWithEntityMetadata withUnmappedField(String name, String value) {
        QueryWithEntityMetadata _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private QueryMetadata queryMetadata;
        private DependentEntityMetadataCollection dependantEntitiesCollection;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder queryMetadata(QueryMetadata queryMetadata) {
            this.queryMetadata = queryMetadata;
            this.changedFields = changedFields.add("QueryMetadata");
            return this;
        }

        public Builder dependantEntitiesCollection(DependentEntityMetadataCollection dependantEntitiesCollection) {
            this.dependantEntitiesCollection = dependantEntitiesCollection;
            this.changedFields = changedFields.add("DependantEntitiesCollection");
            return this;
        }

        public QueryWithEntityMetadata build() {
            QueryWithEntityMetadata _x = new QueryWithEntityMetadata();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.QueryWithEntityMetadata";
            _x.queryMetadata = queryMetadata;
            _x.dependantEntitiesCollection = dependantEntitiesCollection;
            return _x;
        }
    }

    private QueryWithEntityMetadata _copy() {
        QueryWithEntityMetadata _x = new QueryWithEntityMetadata();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.queryMetadata = queryMetadata;
        _x.dependantEntitiesCollection = dependantEntitiesCollection;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("QueryWithEntityMetadata[");
        b.append("QueryMetadata=");
        b.append(this.queryMetadata);
        b.append(", ");
        b.append("DependantEntitiesCollection=");
        b.append(this.dependantEntitiesCollection);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-microsoft-dynamics-0.1.89-sources.jar: microsoft/dynamics/crm/complex/QueryWithEntityMetadata.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "QueryMetadata", 
    "DependantEntitiesCollection"})
@JsonInclude(Include.NON_NULL)
public class QueryWithEntityMetadata implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("QueryMetadata")
    protected QueryMetadata queryMetadata;

    @JsonProperty("DependantEntitiesCollection")
    protected DependentEntityMetadataCollection dependantEntitiesCollection;

    protected QueryWithEntityMetadata() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.QueryWithEntityMetadata";
    }

    @Property(name="QueryMetadata")
    @JsonIgnore
    public Optional<QueryMetadata> getQueryMetadata() {
        return Optional.ofNullable(queryMetadata);
    }

    public QueryWithEntityMetadata withQueryMetadata(QueryMetadata queryMetadata) {
        QueryWithEntityMetadata _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.QueryWithEntityMetadata");
        _x.queryMetadata = queryMetadata;
        return _x;
    }

    @Property(name="DependantEntitiesCollection")
    @JsonIgnore
    public Optional<DependentEntityMetadataCollection> getDependantEntitiesCollection() {
        return Optional.ofNullable(dependantEntitiesCollection);
    }

    public QueryWithEntityMetadata withDependantEntitiesCollection(DependentEntityMetadataCollection dependantEntitiesCollection) {
        QueryWithEntityMetadata _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.QueryWithEntityMetadata");
        _x.dependantEntitiesCollection = dependantEntitiesCollection;
        return _x;
    }

    public QueryWithEntityMetadata withUnmappedField(String name, String value) {
        QueryWithEntityMetadata _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private QueryMetadata queryMetadata;
        private DependentEntityMetadataCollection dependantEntitiesCollection;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder queryMetadata(QueryMetadata queryMetadata) {
            this.queryMetadata = queryMetadata;
            this.changedFields = changedFields.add("QueryMetadata");
            return this;
        }

        public Builder dependantEntitiesCollection(DependentEntityMetadataCollection dependantEntitiesCollection) {
            this.dependantEntitiesCollection = dependantEntitiesCollection;
            this.changedFields = changedFields.add("DependantEntitiesCollection");
            return this;
        }

        public QueryWithEntityMetadata build() {
            QueryWithEntityMetadata _x = new QueryWithEntityMetadata();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.QueryWithEntityMetadata";
            _x.queryMetadata = queryMetadata;
            _x.dependantEntitiesCollection = dependantEntitiesCollection;
            return _x;
        }
    }

    private QueryWithEntityMetadata _copy() {
        QueryWithEntityMetadata _x = new QueryWithEntityMetadata();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.queryMetadata = queryMetadata;
        _x.dependantEntitiesCollection = dependantEntitiesCollection;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("QueryWithEntityMetadata[");
        b.append("QueryMetadata=");
        b.append(this.queryMetadata);
        b.append(", ");
        b.append("DependantEntitiesCollection=");
        b.append(this.dependantEntitiesCollection);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
